import { isDevMode, Component, Inject, Input, EventEmitter, Output, ViewChild, NgModule, CUSTOM_ELEMENTS_SCHEMA } from '@angular/core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import { FormBuilder, ReactiveFormsModule } from '@angular/forms';
import { distinctUntilChanged, debounceTime } from 'rxjs/operators';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatTooltipModule } from '@angular/material/tooltip';
import { CommonModule } from '@angular/common';
import { fromEvent } from 'rxjs';
import { MatIconModule } from '@angular/material/icon';

class ErrorDialog {
    constructor(
    //private overlay: Overlay,
    dialogRef, data) {
        this.dialogRef = dialogRef;
        this.data = data;
    }
    onNoClick() {
        this.dialogRef.close();
    }
    static extractErrorInfo(e, data = {}) {
        return Object.assign(data, {
            showDetails: isDevMode(),
            message: e.message
        });
    }
    /**
     * show error popup if needed
     * @param dialog dialog factory
     * @param e error
     * @param opts
     */
    static openErrorDialog(dialog, e, opts = {}) {
        let config = Object.assign({
            canBeClosed: true,
            closeOnNavigation: true,
            panelClass: 'dialog-layout',
            disableClose: false,
        }, opts);
        config.data = ErrorDialog.extractErrorInfo(e, config.data);
        console.log('openErrorDialog: ', config);
        const dialogRef = dialog.open(ErrorDialog, config);
        dialogRef.disableClose = false;
        dialogRef.afterClosed().subscribe(result => {
            console.log('The dialog was closed', result);
        });
        console.log(e);
        return dialogRef;
    }
}
ErrorDialog.decorators = [
    { type: Component, args: [{
                selector: 'base-error-dialog',
                template: "<h2>ERROR</h2>\n<p>{{data.message}}</p>\n<mat-dialog-content>\n\n  <div class=\"error-info\">\n    <table class=\"info-grid\">\n      <tbody>\n      <tr *ngIf=\"data.status\"><td class=\"label\">Status</td><td class=\"val\">{{data.status}}</td></tr>\n      <tr *ngIf=\"data.code\"><td class=\"label\">Code</td><td class=\"val\">{{data.code}}</td></tr>\n      <tr *ngIf=\"data.link\"><td class=\"label\">Link</td><td class=\"val\">{{data.link}}</td></tr>\n      <tr *ngIf=\"data.request\"><td class=\"label\">Request</td><td class=\"val\">{{data.request}}</td></tr>\n      <tr *ngIf=\"data.operation\"><td class=\"label\">Operation</td><td class=\"val\">{{data.operation}}</td></tr>\n      <tr *ngIf=\"data.component\"><td class=\"label\">Component</td><td class=\"val\">{{data.component}}</td></tr>\n      <tr *ngIf=\"data.developerMessage\"><td class=\"label\">Dev Message:</td><td class=\"val\">{{data.developerMessage}}</td></tr>\n      </tbody>\n    </table>\n  </div>\n\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <button type=\"button\" class=\"cmd\" matDialogClose mat-raised-button color=\"primary\">Close</button>\n</mat-dialog-actions>\n"
            },] }
];
/** @nocollapse */
ErrorDialog.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
class ErrorDialogHandler {
    constructor(dialog) {
        this.dialog = dialog;
    }
    handleError(error) {
        console.warn("ErrorDialogHandler handleError:", error);
        ErrorDialog.openErrorDialog(this.dialog, error);
    }
}

class BaseDateComponent {
    constructor(translate) {
        this.translate = translate;
        this.format = 'day';
        this.formatTip = 'date';
    }
    ngOnInit() {
        if (this.translate != null) {
            this.format = this.translatePattern(this.format, 'yyyy-MM-dd');
            if ('false' !== this.formatTip) {
                this.formatTip = this.translatePattern(this.formatTip, 'yyyy-MM-dd HH:mm:ss Z');
            }
        }
    }
    translatePattern(key, fallback) {
        let value = fallback;
        if (BaseDateComponent.FORMAT_NAMES.indexOf(key) !== -1) {
            this.translate.get(BaseDateComponent.RES_PREFIX + key).subscribe((result) => {
                value = result;
            });
        }
        return value;
    }
}
BaseDateComponent.RES_PREFIX = 'DateFormat.';
BaseDateComponent.FORMAT_NAMES = ['day', 'date', 'full', 'time', 'year'];
BaseDateComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-date',
                template: "<span *ngIf=\"data\"\n      [matTooltip]=\"formatTip != 'false' ? (data|date:formatTip) : null\">{{data|date:format}}</span>\n"
            },] }
];
/** @nocollapse */
BaseDateComponent.ctorParameters = () => [
    { type: TranslateService }
];
BaseDateComponent.propDecorators = {
    data: [{ type: Input }],
    format: [{ type: Input }],
    formatTip: [{ type: Input }]
};

class BaseChangeComponent {
    constructor() {
        this.format = 'day';
    }
    ngOnInit() {
    }
}
BaseChangeComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-change',
                template: "<!--<base-date [data]=\"data?.date\"></base-date>-->\n<base-date\n        [data]=\"data?.date\"\n        [format]=\"format\"\n        formatTip=\"false\" [matTooltip]=\"data?.user\">\n</base-date>\n"
            },] }
];
/** @nocollapse */
BaseChangeComponent.ctorParameters = () => [];
BaseChangeComponent.propDecorators = {
    data: [{ type: Input }],
    format: [{ type: Input }]
};

class TableSearchComponent {
    constructor(fb) {
        this.fb = fb;
        this.changed = new EventEmitter();
        this.debounceTime = 700;
        this.suffix = '*';
    }
    ngOnInit() {
        this.formGroup = this.fb.group({
            keyword: [null, null]
        });
        this.formGroup.valueChanges.pipe(distinctUntilChanged(), debounceTime(this.debounceTime)).subscribe(val => {
            if (!(val.keyword === null)) {
                val.keyword = val.keyword + this.suffix;
            }
            this.changed.emit(val);
        });
    }
}
TableSearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'table-search',
                template: "<form [formGroup]=\"formGroup\">\n  <mat-form-field>\n    <mat-label>Suchen</mat-label>\n    <input matInput formControlName=\"keyword\" type=\"search\" nullValue/>\n  </mat-form-field>\n</form>\n"
            },] }
];
/** @nocollapse */
TableSearchComponent.ctorParameters = () => [
    { type: FormBuilder }
];
TableSearchComponent.propDecorators = {
    changed: [{ type: Output }]
};

class ObjectNotFoundDialogComponent extends ErrorDialog {
    constructor(
    //private overlay: Overlay,
    dialogRef, data) {
        super(dialogRef, data);
        this.dialogRef = dialogRef;
        this.data = data;
    }
    ngOnInit() {
    }
    static openObjectNotFoundDialog(dialog, e, opts = {}) {
        let config = Object.assign({
            canBeClosed: true,
            closeOnNavigation: true,
            panelClass: 'dialog-layout',
            disableClose: false,
        }, opts);
        config.data = ObjectNotFoundDialogComponent.extractErrorInfo(e, config.data);
        console.log('openErrorDialog: ', config);
        const dialogRef = dialog.open(ObjectNotFoundDialogComponent, config);
        dialogRef.disableClose = false;
        return dialogRef;
    }
}
ObjectNotFoundDialogComponent.decorators = [
    { type: Component, args: [{
                selector: 'app-object-not-found-dialog',
                template: "<h2>OBJECT NOT FOUND</h2>\n<p>{{data.message}}</p>\n<mat-dialog-content>\n\n  <div class=\"error-info\">\n    <table class=\"info-grid\">\n      <tbody>\n      <tr *ngIf=\"data.status\"><td class=\"label\">Status</td><td class=\"val\">{{data.status}}</td></tr>\n      <tr *ngIf=\"data.code\"><td class=\"label\">Code</td><td class=\"val\">{{data.code}}</td></tr>\n      <tr *ngIf=\"data.link\"><td class=\"label\">Link</td><td class=\"val\">{{data.link}}</td></tr>\n      <tr *ngIf=\"data.request\"><td class=\"label\">Request</td><td class=\"val\">{{data.request}}</td></tr>\n      <tr *ngIf=\"data.operation\"><td class=\"label\">Operation</td><td class=\"val\">{{data.operation}}</td></tr>\n      <tr *ngIf=\"data.component\"><td class=\"label\">Component</td><td class=\"val\">{{data.component}}</td></tr>\n      <tr *ngIf=\"data.developerMessage\"><td class=\"label\">Dev Message:</td><td class=\"val\">{{data.developerMessage}}</td></tr>\n      </tbody>\n    </table>\n  </div>\n\n</mat-dialog-content>\n\n<mat-dialog-actions>\n  <button mat-raised-button type=\"button\" color=\"accent\" [mat-dialog-close]=\"true\">{{ 'CMD.delete' | translate }}</button>\n  <button mat-button type=\"button\" [mat-dialog-close]=\"false\">{{ 'CMD.cancel' | translate }}</button>\n</mat-dialog-actions>\n"
            },] }
];
/** @nocollapse */
ObjectNotFoundDialogComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];

class SearchFieldComponent {
    constructor() { }
    ngOnInit() {
        if (this.searchElem) {
            fromEvent(this.searchElem.nativeElement, 'keyup')
                .pipe(debounceTime(this.debounceTime), distinctUntilChanged())
                .subscribe(event => {
                let value = this.searchElem.nativeElement.value;
                if (value == '')
                    value = null;
                // let filter = this.dataSource.filterSubject.value;
                // let filter = this.filter;
                // filter.keyword = value
                // this.reload();
                console.log("SearchFieldComponent keyup", value);
            });
        }
    }
    onSearch(ev) {
        console.log("SearchFieldComponent onSearch", ev);
    }
}
SearchFieldComponent.decorators = [
    { type: Component, args: [{
                selector: 'base-search-field',
                template: "<div class=\"field-wrap\">\n    <div class=\"field-box trans-icon\">\n        <input #searchField type=\"text\"/>\n        <button (click)=\"onSearch($event)\" type=\"button\">\n            <i><mat-icon>search</mat-icon></i>\n        </button>\n    </div>\n</div>\n",
                styles: [""]
            },] }
];
/** @nocollapse */
SearchFieldComponent.ctorParameters = () => [];
SearchFieldComponent.propDecorators = {
    searchElem: [{ type: ViewChild, args: ['searchField', { static: true },] }],
    debounceTime: [{ type: Input }]
};

class ChainBaseComp {
}
ChainBaseComp.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ErrorDialog,
                    ObjectNotFoundDialogComponent,
                    TableSearchComponent,
                    BaseChangeComponent,
                    BaseDateComponent,
                    SearchFieldComponent
                ],
                imports: [
                    ReactiveFormsModule,
                    MatFormFieldModule,
                    MatTooltipModule,
                    MatIconModule,
                    CommonModule,
                    MatDialogModule,
                    TranslateModule
                ],
                exports: [
                    ErrorDialog,
                    ObjectNotFoundDialogComponent,
                    TableSearchComponent,
                    BaseChangeComponent,
                    BaseDateComponent
                ],
                entryComponents: [
                    ObjectNotFoundDialogComponent,
                    //ValidationResultDialogComponent,
                    ErrorDialog
                ],
                schemas: [CUSTOM_ELEMENTS_SCHEMA]
            },] }
];

const TYPE_INVOICE = "INVOICE";
/** @deprecated */
class AddressUtils {
    //public static readonly TYPE_INVOICE = "INVOICE";
    constructor() {
    }
    static findAddressByType(address, type) {
        console.log("AddressUtils.findAddressByType");
        console.log("AddressUtils.findAddressByType", address);
        console.log("AddressUtils.findAddressByType", type);
        return address.filter(val => val.type != null).find(val => val.type === TYPE_INVOICE);
        // return address.filter(val => val.type ==true).find(value => value.type == TYPE_INVOICE);
        //  return null;
        // throw new Error("fubar ts")
    }
    static getFormGroup(fb, initial, validators) {
        const group = fb.group({
            type: [null, null],
            street: [null, null],
            houseNumber: [null, null],
            countryCode: [null, null],
            city: [null, null],
            zipCode: [null, null],
            desc: [null, null]
        });
        if (initial) {
            group.patchValue(initial);
        }
        return group;
    }
    static addAddressToFormArray(fa, fb, initial) {
        let formArray = fa;
        formArray.push(this.getFormGroup(fb, initial));
    }
    static addAndGetAddress(fa, fb, initial) {
        let formArray = fa;
        let group = this.getFormGroup(fb, initial);
        formArray.push(group);
        return group;
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { AddressUtils, BaseChangeComponent, BaseDateComponent, ChainBaseComp, ErrorDialog, ErrorDialogHandler, ObjectNotFoundDialogComponent, TableSearchComponent, SearchFieldComponent as ɵa };
//# sourceMappingURL=yukawa-chain-base-angular-comp.js.map
